@@ -84,7 +84,7 @@ BEGIN {
 with 'Log::LogMethods';
 with 'Data::Result::Moo';
 }
-our $VERSION='1.013';
+our $VERSION='1.015';
 
 sub BUILD {
   my ($self)=@_;
@@ -148,7 +148,7 @@ has false_id=>(
 
 has fake_jobs=>(
   isa=>HashRef,
-  is=>'ro',
+  is=>'rw',
   default=>sub { {}}
 );
 
@@ -330,13 +330,20 @@ sub add_by_id {
   return $id;
 }
 
+=item * $self->run_fake_jobs
+
+Runs all current fake jobs
+
+=cut
+
 sub run_fake_jobs {
   my ($self)=@_;
   
   while($self->has_fake_jobs) {
-    foreach my $id (keys %{$self->fake_jobs}) {
-      $self->fake_jobs->{$id}->();
-      delete $self->fake_jobs->{$id};
+    my $fj=$self->fake_jobs;
+    $self->fake_jobs({});
+    while(my (undef,$job)=each (%{$fj})) {
+      $job->();
     }
   }
 }
